@@ -1,6 +1,3 @@
-import six
-
-
 def build_where_clause(**kwargs):
     where_clause = ""
 
@@ -8,8 +5,8 @@ def build_where_clause(**kwargs):
         where = []
 
         for key, value in kwargs.items():
-            if isinstance(value, six.string_types):
-                where.append("{0} = '{1}'".format(key, value.replace("'", "\'")))
+            if isinstance(value, str):
+                where.append("{0} = '{1}'".format(key, value.replace(r"'", r"\'")))
             else:
                 where.append("{0} = {1}".format(key, value))
 
@@ -25,8 +22,8 @@ def build_choose_clause(choices, field):
         where = []
 
         for choice in choices:
-            if isinstance(choice, six.string_types):
-                where.append("'{0}'".format(choice.replace("'", "\'")))
+            if isinstance(choice, str):
+                where.append("'{0}'".format(choice.replace(r"'", r"\'")))
             else:
                 where.append("{0}".format(choice))
 
